% Simple Model Test
% Author
% {today}

---

### Data Plot

![]({data_plot}){{ width=100% }}

### Train set

- **train end date** {train_end_date}
- **seasonality**

{seasonality}

### Prediction Result

![]({pred_plot}){{ width=100% }}

### Error analysis

```{{.python}}
{metric_func}
```

### Error analysis (plot)

![]({error_plot}){{ height=90% }}

### Note

{note}
